@@ -19,13 +19,20 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
+from google.api_core import operation  # type: ignore
+from google.api_core import operation_async  # type: ignore
 from google.cloud.pubsublite_v1.services.admin_service import pagers
 from google.cloud.pubsublite_v1.types import admin
 from google.cloud.pubsublite_v1.types import common
@@ -168,19 +175,19 @@ class AdminServiceAsyncClient:
 
     async def create_topic(
         self,
-        request: admin.CreateTopicRequest = None,
+        request: Union[admin.CreateTopicRequest, dict] = None,
         *,
         parent: str = None,
         topic: common.Topic = None,
         topic_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Topic:
         r"""Creates a new topic.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.CreateTopicRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.CreateTopicRequest, dict]):
                 The request object. Request for CreateTopic.
             parent (:class:`str`):
                 Required. The parent location in which to create the
@@ -259,17 +266,17 @@ class AdminServiceAsyncClient:
 
     async def get_topic(
         self,
-        request: admin.GetTopicRequest = None,
+        request: Union[admin.GetTopicRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Topic:
         r"""Returns the topic configuration.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.GetTopicRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.GetTopicRequest, dict]):
                 The request object. Request for GetTopic.
             name (:class:`str`):
                 Required. The name of the topic whose
@@ -327,10 +334,10 @@ class AdminServiceAsyncClient:
 
     async def get_topic_partitions(
         self,
-        request: admin.GetTopicPartitionsRequest = None,
+        request: Union[admin.GetTopicPartitionsRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> admin.TopicPartitions:
@@ -338,7 +345,7 @@ class AdminServiceAsyncClient:
         topic.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.GetTopicPartitionsRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.GetTopicPartitionsRequest, dict]):
                 The request object. Request for GetTopicPartitions.
             name (:class:`str`):
                 Required. The topic whose partition
@@ -396,17 +403,17 @@ class AdminServiceAsyncClient:
 
     async def list_topics(
         self,
-        request: admin.ListTopicsRequest = None,
+        request: Union[admin.ListTopicsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTopicsAsyncPager:
         r"""Returns the list of topics for the given project.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.ListTopicsRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.ListTopicsRequest, dict]):
                 The request object. Request for ListTopics.
             parent (:class:`str`):
                 Required. The parent whose topics are to be listed.
@@ -475,18 +482,18 @@ class AdminServiceAsyncClient:
 
     async def update_topic(
         self,
-        request: admin.UpdateTopicRequest = None,
+        request: Union[admin.UpdateTopicRequest, dict] = None,
         *,
         topic: common.Topic = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Topic:
         r"""Updates properties of the specified topic.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.UpdateTopicRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.UpdateTopicRequest, dict]):
                 The request object. Request for UpdateTopic.
             topic (:class:`google.cloud.pubsublite_v1.types.Topic`):
                 Required. The topic to update. Its ``name`` field must
@@ -555,17 +562,17 @@ class AdminServiceAsyncClient:
 
     async def delete_topic(
         self,
-        request: admin.DeleteTopicRequest = None,
+        request: Union[admin.DeleteTopicRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes the specified topic.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.DeleteTopicRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.DeleteTopicRequest, dict]):
                 The request object. Request for DeleteTopic.
             name (:class:`str`):
                 Required. The name of the topic to
@@ -618,10 +625,10 @@ class AdminServiceAsyncClient:
 
     async def list_topic_subscriptions(
         self,
-        request: admin.ListTopicSubscriptionsRequest = None,
+        request: Union[admin.ListTopicSubscriptionsRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTopicSubscriptionsAsyncPager:
@@ -629,7 +636,7 @@ class AdminServiceAsyncClient:
         topic.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.ListTopicSubscriptionsRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.ListTopicSubscriptionsRequest, dict]):
                 The request object. Request for ListTopicSubscriptions.
             name (:class:`str`):
                 Required. The name of the topic whose
@@ -697,19 +704,19 @@ class AdminServiceAsyncClient:
 
     async def create_subscription(
         self,
-        request: admin.CreateSubscriptionRequest = None,
+        request: Union[admin.CreateSubscriptionRequest, dict] = None,
         *,
         parent: str = None,
         subscription: common.Subscription = None,
         subscription_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Subscription:
         r"""Creates a new subscription.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.CreateSubscriptionRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.CreateSubscriptionRequest, dict]):
                 The request object. Request for CreateSubscription.
             parent (:class:`str`):
                 Required. The parent location in which to create the
@@ -790,17 +797,17 @@ class AdminServiceAsyncClient:
 
     async def get_subscription(
         self,
-        request: admin.GetSubscriptionRequest = None,
+        request: Union[admin.GetSubscriptionRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Subscription:
         r"""Returns the subscription configuration.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.GetSubscriptionRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.GetSubscriptionRequest, dict]):
                 The request object. Request for GetSubscription.
             name (:class:`str`):
                 Required. The name of the
@@ -861,10 +868,10 @@ class AdminServiceAsyncClient:
 
     async def list_subscriptions(
         self,
-        request: admin.ListSubscriptionsRequest = None,
+        request: Union[admin.ListSubscriptionsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListSubscriptionsAsyncPager:
@@ -872,7 +879,7 @@ class AdminServiceAsyncClient:
         project.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.ListSubscriptionsRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.ListSubscriptionsRequest, dict]):
                 The request object. Request for ListSubscriptions.
             parent (:class:`str`):
                 Required. The parent whose subscriptions are to be
@@ -941,18 +948,18 @@ class AdminServiceAsyncClient:
 
     async def update_subscription(
         self,
-        request: admin.UpdateSubscriptionRequest = None,
+        request: Union[admin.UpdateSubscriptionRequest, dict] = None,
         *,
         subscription: common.Subscription = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Subscription:
         r"""Updates properties of the specified subscription.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.UpdateSubscriptionRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.UpdateSubscriptionRequest, dict]):
                 The request object. Request for UpdateSubscription.
             subscription (:class:`google.cloud.pubsublite_v1.types.Subscription`):
                 Required. The subscription to update. Its ``name`` field
@@ -1023,17 +1030,17 @@ class AdminServiceAsyncClient:
 
     async def delete_subscription(
         self,
-        request: admin.DeleteSubscriptionRequest = None,
+        request: Union[admin.DeleteSubscriptionRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes the specified subscription.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.DeleteSubscriptionRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.DeleteSubscriptionRequest, dict]):
                 The request object. Request for DeleteSubscription.
             name (:class:`str`):
                 Required. The name of the
@@ -1084,21 +1091,106 @@ class AdminServiceAsyncClient:
             request, retry=retry, timeout=timeout, metadata=metadata,
         )
 
+    async def seek_subscription(
+        self,
+        request: Union[admin.SeekSubscriptionRequest, dict] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operation_async.AsyncOperation:
+        r"""Performs an out-of-band seek for a subscription to a
+        specified target, which may be timestamps or named
+        positions within the message backlog. Seek translates
+        these targets to cursors for each partition and
+        orchestrates subscribers to start consuming messages
+        from these seek cursors.
+
+        If an operation is returned, the seek has been
+        registered and subscribers will eventually receive
+        messages from the seek cursors (i.e. eventual
+        consistency), as long as they are using a minimum
+        supported client library version and not a system that
+        tracks cursors independently of Pub/Sub Lite (e.g.
+        Apache Beam, Dataflow, Spark). The seek operation will
+        fail for unsupported clients.
+
+        If clients would like to know when subscribers react to
+        the seek (or not), they can poll the operation. The seek
+        operation will succeed and complete once subscribers are
+        ready to receive messages from the seek cursors for all
+        partitions of the topic. This means that the seek
+        operation will not complete until all subscribers come
+        online.
+
+        If the previous seek operation has not yet completed, it
+        will be aborted and the new invocation of seek will
+        supersede it.
+
+        Args:
+            request (Union[google.cloud.pubsublite_v1.types.SeekSubscriptionRequest, dict]):
+                The request object. Request for SeekSubscription.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.api_core.operation_async.AsyncOperation:
+                An object representing a long-running operation.
+
+                The result type for the operation will be
+                :class:`google.cloud.pubsublite_v1.types.SeekSubscriptionResponse`
+                Response for SeekSubscription long running operation.
+
+        """
+        # Create or coerce a protobuf request object.
+        request = admin.SeekSubscriptionRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.seek_subscription,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Wrap the response in an operation future.
+        response = operation_async.from_gapic(
+            response,
+            self._client._transport.operations_client,
+            admin.SeekSubscriptionResponse,
+            metadata_type=admin.OperationMetadata,
+        )
+
+        # Done; return the response.
+        return response
+
     async def create_reservation(
         self,
-        request: admin.CreateReservationRequest = None,
+        request: Union[admin.CreateReservationRequest, dict] = None,
         *,
         parent: str = None,
         reservation: common.Reservation = None,
         reservation_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Reservation:
         r"""Creates a new reservation.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.CreateReservationRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.CreateReservationRequest, dict]):
                 The request object. Request for CreateReservation.
             parent (:class:`str`):
                 Required. The parent location in which to create the
@@ -1179,17 +1271,17 @@ class AdminServiceAsyncClient:
 
     async def get_reservation(
         self,
-        request: admin.GetReservationRequest = None,
+        request: Union[admin.GetReservationRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Reservation:
         r"""Returns the reservation configuration.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.GetReservationRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.GetReservationRequest, dict]):
                 The request object. Request for GetReservation.
             name (:class:`str`):
                 Required. The name of the reservation whose
@@ -1250,10 +1342,10 @@ class AdminServiceAsyncClient:
 
     async def list_reservations(
         self,
-        request: admin.ListReservationsRequest = None,
+        request: Union[admin.ListReservationsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListReservationsAsyncPager:
@@ -1261,7 +1353,7 @@ class AdminServiceAsyncClient:
         project.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.ListReservationsRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.ListReservationsRequest, dict]):
                 The request object. Request for ListReservations.
             parent (:class:`str`):
                 Required. The parent whose reservations are to be
@@ -1330,18 +1422,18 @@ class AdminServiceAsyncClient:
 
     async def update_reservation(
         self,
-        request: admin.UpdateReservationRequest = None,
+        request: Union[admin.UpdateReservationRequest, dict] = None,
         *,
         reservation: common.Reservation = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Reservation:
         r"""Updates properties of the specified reservation.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.UpdateReservationRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.UpdateReservationRequest, dict]):
                 The request object. Request for UpdateReservation.
             reservation (:class:`google.cloud.pubsublite_v1.types.Reservation`):
                 Required. The reservation to update. Its ``name`` field
@@ -1412,17 +1504,17 @@ class AdminServiceAsyncClient:
 
     async def delete_reservation(
         self,
-        request: admin.DeleteReservationRequest = None,
+        request: Union[admin.DeleteReservationRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes the specified reservation.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.DeleteReservationRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.DeleteReservationRequest, dict]):
                 The request object. Request for DeleteReservation.
             name (:class:`str`):
                 Required. The name of the reservation to delete.
@@ -1476,10 +1568,10 @@ class AdminServiceAsyncClient:
 
     async def list_reservation_topics(
         self,
-        request: admin.ListReservationTopicsRequest = None,
+        request: Union[admin.ListReservationTopicsRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListReservationTopicsAsyncPager:
@@ -1487,7 +1579,7 @@ class AdminServiceAsyncClient:
         reservation.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.ListReservationTopicsRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.ListReservationTopicsRequest, dict]):
                 The request object. Request for ListReservationTopics.
             name (:class:`str`):
                 Required. The name of the reservation whose topics to
@@ -1554,6 +1646,12 @@ class AdminServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
