@@ -14,22 +14,26 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.pubsublite_v1.services.admin_service import pagers
@@ -318,8 +322,15 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
             client_options = client_options_lib.ClientOptions()
 
         # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        if os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false") not in (
+            "true",
+            "false",
+        ):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        use_client_cert = (
+            os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false") == "true"
         )
 
         client_cert_source_func = None
@@ -381,27 +392,24 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def create_topic(
         self,
-        request: admin.CreateTopicRequest = None,
+        request: Union[admin.CreateTopicRequest, dict] = None,
         *,
         parent: str = None,
         topic: common.Topic = None,
         topic_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Topic:
         r"""Creates a new topic.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.CreateTopicRequest):
+            request (Union[google.cloud.pubsublite_v1.types.CreateTopicRequest, dict]):
                 The request object. Request for CreateTopic.
             parent (str):
                 Required. The parent location in which to create the
@@ -480,17 +488,17 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def get_topic(
         self,
-        request: admin.GetTopicRequest = None,
+        request: Union[admin.GetTopicRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Topic:
         r"""Returns the topic configuration.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.GetTopicRequest):
+            request (Union[google.cloud.pubsublite_v1.types.GetTopicRequest, dict]):
                 The request object. Request for GetTopic.
             name (str):
                 Required. The name of the topic whose
@@ -548,10 +556,10 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def get_topic_partitions(
         self,
-        request: admin.GetTopicPartitionsRequest = None,
+        request: Union[admin.GetTopicPartitionsRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> admin.TopicPartitions:
@@ -559,7 +567,7 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
         topic.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.GetTopicPartitionsRequest):
+            request (Union[google.cloud.pubsublite_v1.types.GetTopicPartitionsRequest, dict]):
                 The request object. Request for GetTopicPartitions.
             name (str):
                 Required. The topic whose partition
@@ -617,17 +625,17 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def list_topics(
         self,
-        request: admin.ListTopicsRequest = None,
+        request: Union[admin.ListTopicsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTopicsPager:
         r"""Returns the list of topics for the given project.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.ListTopicsRequest):
+            request (Union[google.cloud.pubsublite_v1.types.ListTopicsRequest, dict]):
                 The request object. Request for ListTopics.
             parent (str):
                 Required. The parent whose topics are to be listed.
@@ -696,18 +704,18 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def update_topic(
         self,
-        request: admin.UpdateTopicRequest = None,
+        request: Union[admin.UpdateTopicRequest, dict] = None,
         *,
         topic: common.Topic = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Topic:
         r"""Updates properties of the specified topic.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.UpdateTopicRequest):
+            request (Union[google.cloud.pubsublite_v1.types.UpdateTopicRequest, dict]):
                 The request object. Request for UpdateTopic.
             topic (google.cloud.pubsublite_v1.types.Topic):
                 Required. The topic to update. Its ``name`` field must
@@ -776,17 +784,17 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def delete_topic(
         self,
-        request: admin.DeleteTopicRequest = None,
+        request: Union[admin.DeleteTopicRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes the specified topic.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.DeleteTopicRequest):
+            request (Union[google.cloud.pubsublite_v1.types.DeleteTopicRequest, dict]):
                 The request object. Request for DeleteTopic.
             name (str):
                 Required. The name of the topic to
@@ -839,10 +847,10 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def list_topic_subscriptions(
         self,
-        request: admin.ListTopicSubscriptionsRequest = None,
+        request: Union[admin.ListTopicSubscriptionsRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTopicSubscriptionsPager:
@@ -850,7 +858,7 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
         topic.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.ListTopicSubscriptionsRequest):
+            request (Union[google.cloud.pubsublite_v1.types.ListTopicSubscriptionsRequest, dict]):
                 The request object. Request for ListTopicSubscriptions.
             name (str):
                 Required. The name of the topic whose
@@ -918,19 +926,19 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def create_subscription(
         self,
-        request: admin.CreateSubscriptionRequest = None,
+        request: Union[admin.CreateSubscriptionRequest, dict] = None,
         *,
         parent: str = None,
         subscription: common.Subscription = None,
         subscription_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Subscription:
         r"""Creates a new subscription.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.CreateSubscriptionRequest):
+            request (Union[google.cloud.pubsublite_v1.types.CreateSubscriptionRequest, dict]):
                 The request object. Request for CreateSubscription.
             parent (str):
                 Required. The parent location in which to create the
@@ -1011,17 +1019,17 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def get_subscription(
         self,
-        request: admin.GetSubscriptionRequest = None,
+        request: Union[admin.GetSubscriptionRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Subscription:
         r"""Returns the subscription configuration.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.GetSubscriptionRequest):
+            request (Union[google.cloud.pubsublite_v1.types.GetSubscriptionRequest, dict]):
                 The request object. Request for GetSubscription.
             name (str):
                 Required. The name of the
@@ -1082,10 +1090,10 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def list_subscriptions(
         self,
-        request: admin.ListSubscriptionsRequest = None,
+        request: Union[admin.ListSubscriptionsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListSubscriptionsPager:
@@ -1093,7 +1101,7 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
         project.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.ListSubscriptionsRequest):
+            request (Union[google.cloud.pubsublite_v1.types.ListSubscriptionsRequest, dict]):
                 The request object. Request for ListSubscriptions.
             parent (str):
                 Required. The parent whose subscriptions are to be
@@ -1162,18 +1170,18 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def update_subscription(
         self,
-        request: admin.UpdateSubscriptionRequest = None,
+        request: Union[admin.UpdateSubscriptionRequest, dict] = None,
         *,
         subscription: common.Subscription = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Subscription:
         r"""Updates properties of the specified subscription.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.UpdateSubscriptionRequest):
+            request (Union[google.cloud.pubsublite_v1.types.UpdateSubscriptionRequest, dict]):
                 The request object. Request for UpdateSubscription.
             subscription (google.cloud.pubsublite_v1.types.Subscription):
                 Required. The subscription to update. Its ``name`` field
@@ -1244,17 +1252,17 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def delete_subscription(
         self,
-        request: admin.DeleteSubscriptionRequest = None,
+        request: Union[admin.DeleteSubscriptionRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes the specified subscription.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.DeleteSubscriptionRequest):
+            request (Union[google.cloud.pubsublite_v1.types.DeleteSubscriptionRequest, dict]):
                 The request object. Request for DeleteSubscription.
             name (str):
                 Required. The name of the
@@ -1307,9 +1315,9 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def seek_subscription(
         self,
-        request: admin.SeekSubscriptionRequest = None,
+        request: Union[admin.SeekSubscriptionRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1342,7 +1350,7 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
         supersede it.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.SeekSubscriptionRequest):
+            request (Union[google.cloud.pubsublite_v1.types.SeekSubscriptionRequest, dict]):
                 The request object. Request for SeekSubscription.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -1393,19 +1401,19 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def create_reservation(
         self,
-        request: admin.CreateReservationRequest = None,
+        request: Union[admin.CreateReservationRequest, dict] = None,
         *,
         parent: str = None,
         reservation: common.Reservation = None,
         reservation_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Reservation:
         r"""Creates a new reservation.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.CreateReservationRequest):
+            request (Union[google.cloud.pubsublite_v1.types.CreateReservationRequest, dict]):
                 The request object. Request for CreateReservation.
             parent (str):
                 Required. The parent location in which to create the
@@ -1486,17 +1494,17 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def get_reservation(
         self,
-        request: admin.GetReservationRequest = None,
+        request: Union[admin.GetReservationRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Reservation:
         r"""Returns the reservation configuration.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.GetReservationRequest):
+            request (Union[google.cloud.pubsublite_v1.types.GetReservationRequest, dict]):
                 The request object. Request for GetReservation.
             name (str):
                 Required. The name of the reservation whose
@@ -1557,10 +1565,10 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def list_reservations(
         self,
-        request: admin.ListReservationsRequest = None,
+        request: Union[admin.ListReservationsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListReservationsPager:
@@ -1568,7 +1576,7 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
         project.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.ListReservationsRequest):
+            request (Union[google.cloud.pubsublite_v1.types.ListReservationsRequest, dict]):
                 The request object. Request for ListReservations.
             parent (str):
                 Required. The parent whose reservations are to be
@@ -1637,18 +1645,18 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def update_reservation(
         self,
-        request: admin.UpdateReservationRequest = None,
+        request: Union[admin.UpdateReservationRequest, dict] = None,
         *,
         reservation: common.Reservation = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> common.Reservation:
         r"""Updates properties of the specified reservation.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.UpdateReservationRequest):
+            request (Union[google.cloud.pubsublite_v1.types.UpdateReservationRequest, dict]):
                 The request object. Request for UpdateReservation.
             reservation (google.cloud.pubsublite_v1.types.Reservation):
                 Required. The reservation to update. Its ``name`` field
@@ -1719,17 +1727,17 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def delete_reservation(
         self,
-        request: admin.DeleteReservationRequest = None,
+        request: Union[admin.DeleteReservationRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes the specified reservation.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.DeleteReservationRequest):
+            request (Union[google.cloud.pubsublite_v1.types.DeleteReservationRequest, dict]):
                 The request object. Request for DeleteReservation.
             name (str):
                 Required. The name of the reservation to delete.
@@ -1783,10 +1791,10 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
 
     def list_reservation_topics(
         self,
-        request: admin.ListReservationTopicsRequest = None,
+        request: Union[admin.ListReservationTopicsRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListReservationTopicsPager:
@@ -1794,7 +1802,7 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
         reservation.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.ListReservationTopicsRequest):
+            request (Union[google.cloud.pubsublite_v1.types.ListReservationTopicsRequest, dict]):
                 The request object. Request for ListReservationTopics.
             name (str):
                 Required. The name of the reservation whose topics to
@@ -1861,6 +1869,19 @@ class AdminServiceClient(metaclass=AdminServiceClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
