@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,27 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.cloud.pubsublite_v1.types import common
 from google.cloud.pubsublite_v1.types import topic_stats
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import TopicStatsServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import TopicStatsServiceGrpcAsyncIOTransport
 from .client import TopicStatsServiceClient
@@ -49,31 +51,26 @@ class TopicStatsServiceAsyncClient:
 
     topic_path = staticmethod(TopicStatsServiceClient.topic_path)
     parse_topic_path = staticmethod(TopicStatsServiceClient.parse_topic_path)
-
     common_billing_account_path = staticmethod(
         TopicStatsServiceClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         TopicStatsServiceClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(TopicStatsServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         TopicStatsServiceClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         TopicStatsServiceClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         TopicStatsServiceClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(TopicStatsServiceClient.common_project_path)
     parse_common_project_path = staticmethod(
         TopicStatsServiceClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(TopicStatsServiceClient.common_location_path)
     parse_common_location_path = staticmethod(
         TopicStatsServiceClient.parse_common_location_path
@@ -81,7 +78,8 @@ class TopicStatsServiceAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -96,7 +94,7 @@ class TopicStatsServiceAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -113,7 +111,7 @@ class TopicStatsServiceAsyncClient:
 
     @property
     def transport(self) -> TopicStatsServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             TopicStatsServiceTransport: The transport used by the client instance.
@@ -127,12 +125,12 @@ class TopicStatsServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, TopicStatsServiceTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the topic stats service client.
+        """Instantiates the topic stats service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -164,7 +162,6 @@ class TopicStatsServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = TopicStatsServiceClient(
             credentials=credentials,
             transport=transport,
@@ -174,9 +171,9 @@ class TopicStatsServiceAsyncClient:
 
     async def compute_message_stats(
         self,
-        request: topic_stats.ComputeMessageStatsRequest = None,
+        request: Union[topic_stats.ComputeMessageStatsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> topic_stats.ComputeMessageStatsResponse:
@@ -184,10 +181,9 @@ class TopicStatsServiceAsyncClient:
         given topic and partition.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.ComputeMessageStatsRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.ComputeMessageStatsRequest, dict]):
                 The request object. Compute statistics about a range of
                 messages in a given topic and partition.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -202,26 +198,13 @@ class TopicStatsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = topic_stats.ComputeMessageStatsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.compute_message_stats,
-            default_retry=retries.Retry(
-                initial=0.1,
-                maximum=60.0,
-                multiplier=1.3,
-                predicate=retries.if_exception_type(
-                    exceptions.Aborted,
-                    exceptions.DeadlineExceeded,
-                    exceptions.InternalServerError,
-                    exceptions.ServiceUnavailable,
-                    exceptions.Unknown,
-                ),
-            ),
-            default_timeout=600.0,
+            default_timeout=None,
             client_info=DEFAULT_CLIENT_INFO,
         )
 
@@ -239,9 +222,9 @@ class TopicStatsServiceAsyncClient:
 
     async def compute_head_cursor(
         self,
-        request: topic_stats.ComputeHeadCursorRequest = None,
+        request: Union[topic_stats.ComputeHeadCursorRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> topic_stats.ComputeHeadCursorResponse:
@@ -254,10 +237,9 @@ class TopicStatsServiceAsyncClient:
         messages in the partition.
 
         Args:
-            request (:class:`google.cloud.pubsublite_v1.types.ComputeHeadCursorRequest`):
+            request (Union[google.cloud.pubsublite_v1.types.ComputeHeadCursorRequest, dict]):
                 The request object. Compute the current head cursor for
                 a partition.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -271,7 +253,6 @@ class TopicStatsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = topic_stats.ComputeHeadCursorRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -294,6 +275,63 @@ class TopicStatsServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def compute_time_cursor(
+        self,
+        request: Union[topic_stats.ComputeTimeCursorRequest, dict] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> topic_stats.ComputeTimeCursorResponse:
+        r"""Compute the corresponding cursor for a publish or
+        event time in a topic partition.
+
+        Args:
+            request (Union[google.cloud.pubsublite_v1.types.ComputeTimeCursorRequest, dict]):
+                The request object. Compute the corresponding cursor for
+                a publish or event time in a topic partition.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.pubsublite_v1.types.ComputeTimeCursorResponse:
+                Response containing the cursor
+                corresponding to a publish or event time
+                in a topic partition.
+
+        """
+        # Create or coerce a protobuf request object.
+        request = topic_stats.ComputeTimeCursorRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.compute_time_cursor,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("topic", request.topic),)),
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
