@@ -14,22 +14,26 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.cloud.pubsublite_v1.types import common
 from google.cloud.pubsublite_v1.types import topic_stats
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -286,8 +290,15 @@ class TopicStatsServiceClient(metaclass=TopicStatsServiceClientMeta):
             client_options = client_options_lib.ClientOptions()
 
         # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        if os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false") not in (
+            "true",
+            "false",
+        ):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        use_client_cert = (
+            os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false") == "true"
         )
 
         client_cert_source_func = None
@@ -349,13 +360,14 @@ class TopicStatsServiceClient(metaclass=TopicStatsServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def compute_message_stats(
         self,
-        request: topic_stats.ComputeMessageStatsRequest = None,
+        request: Union[topic_stats.ComputeMessageStatsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> topic_stats.ComputeMessageStatsResponse:
@@ -363,7 +375,7 @@ class TopicStatsServiceClient(metaclass=TopicStatsServiceClientMeta):
         given topic and partition.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.ComputeMessageStatsRequest):
+            request (Union[google.cloud.pubsublite_v1.types.ComputeMessageStatsRequest, dict]):
                 The request object. Compute statistics about a range of
                 messages in a given topic and partition.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -405,9 +417,9 @@ class TopicStatsServiceClient(metaclass=TopicStatsServiceClientMeta):
 
     def compute_head_cursor(
         self,
-        request: topic_stats.ComputeHeadCursorRequest = None,
+        request: Union[topic_stats.ComputeHeadCursorRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> topic_stats.ComputeHeadCursorResponse:
@@ -420,7 +432,7 @@ class TopicStatsServiceClient(metaclass=TopicStatsServiceClientMeta):
         messages in the partition.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.ComputeHeadCursorRequest):
+            request (Union[google.cloud.pubsublite_v1.types.ComputeHeadCursorRequest, dict]):
                 The request object. Compute the current head cursor for
                 a partition.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -461,9 +473,9 @@ class TopicStatsServiceClient(metaclass=TopicStatsServiceClientMeta):
 
     def compute_time_cursor(
         self,
-        request: topic_stats.ComputeTimeCursorRequest = None,
+        request: Union[topic_stats.ComputeTimeCursorRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> topic_stats.ComputeTimeCursorResponse:
@@ -471,7 +483,7 @@ class TopicStatsServiceClient(metaclass=TopicStatsServiceClientMeta):
         event time in a topic partition.
 
         Args:
-            request (google.cloud.pubsublite_v1.types.ComputeTimeCursorRequest):
+            request (Union[google.cloud.pubsublite_v1.types.ComputeTimeCursorRequest, dict]):
                 The request object. Compute the corresponding cursor for
                 a publish or event time in a topic partition.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -511,6 +523,19 @@ class TopicStatsServiceClient(metaclass=TopicStatsServiceClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
